package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.26.3 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.26.3) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,`*``!````?!4``#0````X@0````0`!30`(``'
M`"@`%@`5``8````T````-````#0```#@````X`````0````$`````P```!0!
M```4`0``%`$``!@````8````!`````$````!````````````````````0'T`
M`$!]```%```````!``$```#`?0``P'T!`,!]`0!\`@``K!(```8```````$`
M`@```,A]``#(?0$`R'T!`/````#P````!@````0```!1Y71D````````````
M```````````````&````$````%+E=&3`?0``P'T!`,!]`0!``@``0`(```0`
M```!````+VQI8B]L9"UM=7-L+6%R;6AF+G-O+C$`$0```$\````(````"```
M``&````E0`2`*(`0`:"&4("``0``"R`$C3B`$D&*!`@(3P```%````!4````
M60```%H```!@````80```&(`````````9```````````````90```&8```!H
M```````````````!KS3H:G^:?.K3[P[.WD<M;\7?'R[%F[:XC?$.U&34?'94
M/)0A_^0.V7%8'/JA;&#"Y3\LL@&+;^)'Q@%8[Y=YN^.2?%7#/-)GK\QFB`=P
MTT-%U>PS8MOM?ZF<F^"G`@J_VE<;H^#[20``````````````````````````
M"!`````````#``<```````"``0```````P`1``P``````````````!(```#3
M`0`````````````2````%```````````````$0```/D!`````````````!$`
M``!U`0`````````````2````&P``````````````$@```+(!````````````
M`!(````C```````````````2````*@``````````````$@````8"````````
M`````!(```"^`0`````````````2````,P``````````````(````$X#````
M`````````"$```!+```````````````2````40``````````````$@```%@`
M`````````````!(````4`P`````````````2````!0,`````````````$@``
M`(L"`````````````!(```!?```````````````2````+`(`````````````
M$@```&8``````````````!(```#``@`````````````2````;0``````````
M````$@```'4``````````````!(```"I`@`````````````2````?0``````
M````````$@```(,``````````````!(```",```````````````@````_@(`
M````````````$@```*@``````````````!(```"M```````````````2````
M%P(`````````````$0```,<"`````````````!(```!9`@`````````````2
M````)`,`````````````$@```$L"`````````````!(```!R`P``````````
M```2````T@(`````````````$0```$T#`````````````!$```!]`@``````
M```````2````.@,`````````````$@```$\#`````````````!$```"T````
M```````````2````,@,`````````````$@```+T``````````````!$```"#
M`0`````````````2````SP``````````````(@```-X``````````````"``
M``#T```````````````2````]@(`````````````$@```&D"````````````
M`!(```#Y```````````````2````_P``````````````(````+0"````````
M`````!(````9`0`````````````2````HP$`````````````$@```!X!````
M`````````!(```"9`@`````````````2````D@$`````````````$@```"0!
M`````````````!(````U`0`````````````2````)P(`````````````$@``
M`'X``````````````!(````X`@`````````````2````<@(`````````````
M$@```"L#`````````````!(````[`0`````````````2````'`,`````````
M````$@```$\!`````````````!(````B`@`````````````2````X0$`````
M````````$@```%8!`````````````!(```!=`0`````````````2````3`,`
M````````````(0```&X!`````````````!(```!4!```;)`!```````0`!(`
M1P,``!`3``!L`@``$@`)`/,!```4/@``!````!(`"@"T`P``,#$```@)```2
M``D`9`0``+P]``!8````$@`)`)$#``"8*@``!````!(`"0##`P``"!````0`
M```2``<`UP,``#@Z``"$`P``$@`)`!@$```\@`$``````!``$@!&!```G"H`
M`"0"```2``D`!`0``#R``0``````$``2`*(#``!\,```M````!(`"0#!`P``
MF"@``%P````2``D`R0,``/PO``!H````$@`)`/<#``#`+```'````!(`"0`0
M!```;)`!```````0`!(`7P0``&R0`0``````$``2`%<#``"@%0``7````!(`
M"0`F!```W"P```0!```2``D`[0,``#B``0`$````$0`1`#\$```\@`$`````
M`!``$0`)!```?!4````````2``D`8`,``&0P```8````$@`)`'L#``!@*0``
M.`$``!(`"0!3!```;)`!```````0`!(`,@0``.`M```<`@``$@`)``!L:6)P
M97)L+G-O`&]P96YD:7(`<W1D97)R`')E86QL;V,`86-C97-S`'-N<')I;G1F
M`%]?9&5R96=I<W1E<E]F<F%M95]I;F9O`&QS965K`&=E='!I9`!S=')C;7``
M;65M<V5T`'5N;&EN:P!M96UM;W9E`'-T<FYC;7``;'-T870`8VQO<V5D:7(`
M7TE435]D97)E9VES=&5R5$U#;&]N951A8FQE`&]P96X`<W1R<W1R`')E861L
M:6YK`%]?<W1A8VM?8VAK7V=U87)D`%]?8WAA7V9I;F%L:7IE`%]?<F5G:7-T
M97)?9G)A;65?:6YF;P!E>&ET`&-L;W-E`%])5$U?<F5G:7-T97)434-L;VYE
M5&%B;&4`<F5A9`!R;61I<@!?7V5R<FYO7VQO8V%T:6]N`&UK9&ER`'!T:')E
M861?9V5T<W!E8VEF:6,`;65M8W!Y`'-T<FQE;@!?7W-T86-K7V-H:U]F86EL
M`&=E='5I9`!097)L7W-Y<U]T97)M`%!E<FQ?<WES7VEN:70S`%!E<FQ?871F
M;W)K7VQO8VL`<&5R;%]C;VYS=')U8W0`4&5R;%]G971?<W8`4&5R;%]C<F]A
M:U]N;V-O;G1E>'0`4&5R;%]A=E]S:&EF=`!097)L7W-V7S)P=E]F;&%G<P!?
M9FEN:0!03%]D;U]U;F1U;7``4&5R;%]N97=84U]F;&%G<P!03%]T:')?:V5Y
M`'!E<FQ?9G)E90!097)L7VUG7W-E=`!097)L7V%T9F]R:U]U;FQO8VL`4&5R
M;%]S=E]S971P=@!097)L7V=V7V9E=&-H<'8`<&5R;%]R=6X`4&5R;%]N97=8
M4P!P97)L7V1E<W1R=6-T`%!E<FQ?879?9F5T8V@`8F]O=%]$>6YA3&]A9&5R
M`'!E<FQ?<&%R<V4`4&5R;%]S869E<WES;6%L;&]C`'!E<FQ?86QL;V,`4$Q?
M;65M;W)Y7W=R87``;&EB8RYM=7-L+6%R;6AF+G-O+C$`9G!R:6YT9@!S=')D
M=7``<'1H<F5A9%]A=&9O<FL`<F5A9&1I<@!S<')I;G1F`'-T<F-H<@!S=')T
M;VL`<W1R;F-P>0!?7VQI8F-?<W1A<G1?;6%I;@!?7U]E;G9I<F]N`%]S=&%R
M=%]C`&=E=%]U<V5R;F%M95]F<F]M7V=E='!W=6ED`'!A<E]C=7)R96YT7V5X
M96-?<')O8P!P87)?8W5R<F5N=%]E>&5C`'!A<E]S971U<%]L:6)P871H`'!A
M<E]M:W1M<&1I<@!X<U]I;FET`'!A<E]E;G9?8VQE86X`6%-?26YT97)N86QS
M7U!!4E]"3T]4`&UY7W!A<E]P;`!P87)?8F%S96YA;64`7U]B<W-?<W1A<G0`
M7U]E;F1?7P!?7V)S<U]S=&%R=%]?`'!A<E]D:7)N86UE`'!A<E]I;FET7V5N
M=@!?961A=&$`<&%R7V9I;F1P<F]G`%]?8G-S7V5N9%]?`%]E;F0`<&%R7V-L
M96%N=7``+W5S<B]L:6(O<&5R;#4O8V]R95]P97)L+T-/4D4```#`?0$`%P``
M`,1]`0`7````O'\!`!<```#(?P$`%P```-1_`0`7`````(`!`!<````(@`$`
M%P````R``0`7````%(`!`!<````8@`$`%P```!R``0`7````((`!`!<````D
M@`$`%P```"R``0`7````,(`!`!<````X@`$`%P```,!_`0`5!0``Q'\!`!4&
M``#,?P$`%0X``-!_`0`5'P``V'\!`!4C``#<?P$`%2D``.!_`0`5+0``Y'\!
M`!4P``#H?P$`%3(``.Q_`0`5,P``\'\!`!4X``#T?P$`%3T``/A_`0`5/@``
M_'\!`!5#``#$?@$`%@,``,A^`0`6!```S'X!`!8'``#0?@$`%@@``-1^`0`6
M"0``V'X!`!8*``#<?@$`%@L``.!^`0`6#```Y'X!`!8-``#H?@$`%@X``.Q^
M`0`6$```\'X!`!81``#T?@$`%A(``/A^`0`6$P``_'X!`!84````?P$`%A4`
M``1_`0`6%@``"'\!`!87```,?P$`%A@``!!_`0`6&0``%'\!`!8:```8?P$`
M%AL``!Q_`0`6'```('\!`!8=```D?P$`%AX``"A_`0`6(```+'\!`!8A```P
M?P$`%B(``#1_`0`6)```.'\!`!8E```\?P$`%B8``$!_`0`6)P``1'\!`!8H
M``!(?P$`%BL``$Q_`0`6+```4'\!`!8N``!4?P$`%B\``%A_`0`6,0``7'\!
M`!8R``!@?P$`%C,``&1_`0`6-```:'\!`!8U``!L?P$`%C8``'!_`0`6-P``
M='\!`!8Y``!X?P$`%CH``'Q_`0`6.P``@'\!`!8\``"$?P$`%C\``(A_`0`6
M0```C'\!`!9!``"0?P$`%D(``)1_`0`61```F'\!`!9%``"<?P$`%D8``*!_
M`0`61P``I'\!`!9(``"H?P$`%DD``*Q_`0`62@``L'\!`!9+``"T?P$`%DP`
M`+A_`0`63@```4`MZ0%`O>@>_R_A!.`MY03@G^4.X(_@"/"^Y91N`0``QH_B
M%LJ,XI3^O.4`QH_B%LJ,XHS^O.4`QH_B%LJ,XH3^O.4`QH_B%LJ,XGS^O.4`
MQH_B%LJ,XG3^O.4`QH_B%LJ,XFS^O.4`QH_B%LJ,XF3^O.4`QH_B%LJ,XES^
MO.4`QH_B%LJ,XE3^O.4`QH_B%LJ,XDS^O.4`QH_B%LJ,XD3^O.4`QH_B%LJ,
MXCS^O.4`QH_B%LJ,XC3^O.4`QH_B%LJ,XBS^O.4`QH_B%LJ,XB3^O.4`QH_B
M%LJ,XAS^O.4`QH_B%LJ,XA3^O.4`QH_B%LJ,X@S^O.4`QH_B%LJ,X@3^O.4`
MQH_B%LJ,XOS]O.4`QH_B%LJ,XO3]O.4`QH_B%LJ,XNS]O.4`QH_B%LJ,XN3]
MO.4`QH_B%LJ,XMS]O.4`QH_B%LJ,XM3]O.4`QH_B%LJ,XLS]O.4`QH_B%LJ,
MXL3]O.4`QH_B%LJ,XKS]O.4`QH_B%LJ,XK3]O.4`QH_B%LJ,XJS]O.4`QH_B
M%LJ,XJ3]O.4`QH_B%LJ,XIS]O.4`QH_B%LJ,XI3]O.4`QH_B%LJ,XHS]O.4`
MQH_B%LJ,XH3]O.4`QH_B%LJ,XGS]O.4`QH_B%LJ,XG3]O.4`QH_B%LJ,XFS]
MO.4`QH_B%LJ,XF3]O.4`QH_B%LJ,XES]O.4`QH_B%LJ,XE3]O.4`QH_B%LJ,
MXDS]O.4`QH_B%LJ,XD3]O.4`QH_B%LJ,XCS]O.4`QH_B%LJ,XC3]O.4`QH_B
M%LJ,XBS]O.4`QH_B%LJ,XB3]O.4`QH_B%LJ,XAS]O.4`QH_B%LJ,XA3]O.4`
MQH_B%LJ,X@S]O.4`QH_B%LJ,X@3]O.4`QH_B%LJ,XOS\O.4`QH_B%LJ,XO3\
MO.4`QH_B%LJ,XNS\O.4`QH_B%LJ,XN3\O.4`QH_B%LJ,XMS\O.4`QH_B%LJ,
MXM3\O.4`QH_B%LJ,XLS\O.4`QH_B%LJ,XL3\O.4`QH_B%LJ,XKS\O.4`QH_B
M%LJ,XK3\O.4`QH_B%LJ,XJS\O.5P0"WI(-!-XAP`C>48$(WE%""-Y1@0C>(4
M((WB'`"-XOA!G^6J___K]#&?Y01`C^`#,)3G##"-Y>@QG^4,()WE`S"4YP(0
MH.$#`*#A$#"-Y5K__^O0,9_E`S"4YP!@T^7(,9_E``!6XP-0E.<+```:?/__
MZ[@AG^4``%#C`B"/X!``@N4!```:`0"@XYG__^NJ___K``"5Y<#__^M59L#E
M``"5Y;W__^ON,]#E`C"#X^XSP.4``)7EN/__Z^XST.4!,(/C[C/`Y1P`G>4%
M`(#B!P%PXP8``)I8,9_E6`&?Y0,PE.<``(_@`Q"@X0PPC>4@___K``&@X8K_
M_^L8P)WE."&?Y0`0G.4"((_@`!"`Y2P1G^4(`(+E`1"/X`00@.4@$9_E`#"@
MX0$0C^``$)'E"!"`Y1`1G^4!$(_@#!"@Y000H.,$$(+E`1"@XQP@G>4!`%+A
M+0``R@`0H.,-`8+BZ$"?Y0`1@^<`$(WEX!"?Y01`C^`#((+B`1"/X!``E.4F
M___K`%!0X@(``!H0`)3E7O__ZP!0H.&X0)_E!$"/X!``E.4^___KK`"?Y0``
MC^#7`P#K``!0XPP``!H,,)3E``!3XP,``!J0`)_E``"/X,\#`.L,`(3EA#"?
MY0,PC^`,`)/E``!0XP````HN"@#K<#"?Y0,PC^`0`)/E</__Z\K^_^L%`*#A
M(-"-XG"`O>@!X9SG`1"!X@3@H.7+___J=&L!`$0!``!``0``#`$``"`!``#$
M;`$`)`$``),J```X;`$`LBP``/AK`0"5+```T&L!`&04``"D:P$`'2H``+(I
M``!D:P$`3&L!``"PH.,`X*#C$!"?Y0$0C^`-`*#A#\#`XPS0H.$```#K.&@!
M`!]`+>E`,)_E0""?Y0,PC^`"()/G"""-Y30@G^4"()/G#""-Y0`@H.,$((WE
M)""?Y0(PD^<$((#B`#"-Y0`0D.4(,)WE#`"=Y?3^_^L$:0$`'`$```0!```0
M`0``0`"?Y4`PG^5`()_E``"/X`,PC^```%/A`B"/X![_+P$L,)_E"-!-X@,P
MDN<$,(WE``!3XP$```H(T(WB$_\OX0C0C>(>_R_A+&H!`"AJ`0"<:`$`&`$`
M`$P`G^5,,)_E``"/X`,PC^``$$/@01&@X3P@G^6A'X'@P1"PX0(@C^`>_R\!
M+#"?Y0C03>(#,)+G!#"-Y0``4^,!```*"-"-XA/_+^$(T(WB'O\OX=AI`0#4
M:0$`.&@!`#@!``!H,)_E$$`MZ0,PC^``,-/E7$"?Y0``4^,$0(_@$("]&%`P
MG^4#,)3G``!3XP(```I$,)_E`P"?Y[[^_^O`___K.#"?Y0,PE.<``%/C`@``
M"BP`G^4``(_@7_[_ZP$@H.,@,)_E`S"/X``@P^40@+WH=&D!`.!G`0`P`0``
M#&D!`!0!```H9@``&&D!`#`PG^4P()_E`S"/X`(PD^<``%/C!@``"A!`+>D<
M$)_E'`"?Y0$0C^```(_@H?[_ZQ!`O>BU___J9&<!`#0!``#0:`$`R&4``/!/
M+>G(.Y_ER"N?Y57?3>(#,(_@`C"3YPP@C>("P*#A!#"-Y0`PD^5<X(#B3#&-
MY1PP@.($$)/D,1^_Y@,`7N$$$(SD^O__&D#`H.,"$*#A(."1Y30PD>4$((+B
M#C`CX`C@D>4`$)'E#C`CX`$P(^#C/Z#A`<!<XCPP@N7R__\:5#N?Y0S@G>4$
M<)#E"%"`XF`!E>@`D)#E`^".X`8@)>`'(`+@".".X.GMCN`&("+@9T&@X0+@
MCN`0()WE!,`EX`G`#.`#((+@!<`LX`8@@N!IH:#A`L",X!0@G>4*$"3@#A`!
MX`,@@N`%((+@!!`AX.[-C.`"$('@;N&@X1@@G>4.L"K@#+`+X`,@@N#L'8'@
M!"""X&S!H.$*L"O@'$"=Y0*PB^`,("[@`T"$X`$@`N`*H(3@#B`BX.&]B^`*
M((+@81&@X2"@G>4!0"S@`Z"*X`M`!.#K+8+@#N"*X&NQH.$,0"3@)*"=Y0Y`
MA.`+X"'@`Z"*X`+@#N`,P(K@`>`NX.)-A.`,X([@8B&@X2C`G>4"H"O@`\",
MX`2@"N`!$(S@"Z`JX.3MCN`!H(K@9$&@X2P0G>4$P"+@`Q"!X`[`#.`+L('@
M`L`LX.ZMBN`+P(S@;N&@X3"PG>4.$"3@`["+X`H0`>#JS8S@`B"+X&JAH.$$
M$"'@-+"=Y0(0@>`*("[@`["+X`P@`N#L'8'@!$"+X&S!H.$.("+@.+"=Y00@
M@N`,0"K@`["+X`%`!.#A+8+@#N"+X&$1H.$*0"3@/+"=Y0Y`A.`!X"S@`["+
MX`+@#N`*H(O@#.`NX.)-A.`*X([@8B&@X4"@G>4"L"'@`Z"*X`2P"^`,P(K@
M`;`KX.3MCN`,L(O@9$&@X43`G>4$H"+@`\",X`Z@"N#NO8O@`1",X&[AH.$"
MH"K@2,"=Y0&@BN`.$"3@`\",X`L0`>#KK8K@!!`AX&NQH.$"((S@3,"=Y0(@
M@>`+$"[@`\",X`H0`>#J+8+@#A`AX&JAH.$$0(S@4,"=Y01`@>`*$"O@`\",
MX`(0`>`+$"'@#N",X.)-A.`.X('@8B&@X500G>4"P"K@`Q"!X`3`#.`+L('@
M"L`LX.3MCN`+P(S@9$&@X5BPG>4$$"+@`S"+X`X0`>`*H(/@`A`AX(0XG^4*
M$('@7*"=Y>[-C.`#H(K@;N&@X0(@BN`.H"3@#*`JX`H@@N!@H)WE[!V!X`.@
MBN!LP:#A!$"*X`R@+N`!H"K@"D"$X&2@G>7A+8+@`Z"*X&$1H.$.X(K@`:`L
MX`*@*N`*X([@:*"=Y>)-A.`#H(K@8B&@X0S`BN`"H"'@!*`JX`K`C.!LH)WE
MY.V.X`.@BN!D0:#A`1"*X`2@(N`.H"K@"A"!X'"@G>7NS8S@`Z"*X&[AH.$"
M((K@#J`DX`R@*N`*((+@=*"=Y>P=@>`#H(K@;,&@X01`BN`,H"[@`:`JX`I`
MA.!XH)WEX2V"X`.@BN!A$:#A#N"*X`&@+.`"H"K@"N".X'R@G>7B383@`Z"*
MX&(AH.$,P(K@`J`AX`2@*N`*P(S@@*"=Y>3MCN`#H(K@9$&@X0$0BN`$H"+@
M#J`JX`H0@>"$H)WE[LV,X`.@BN!NX:#A`B"*X`Z@).`,H"K@"B""X(B@G>7L
M'8'@`Z"*X&S!H.$$0(K@#*`NX`&@*N`*0(3@C*"=Y>$M@N`#H(K@81&@X0[@
MBN`!H"S@`J`JX`K@CN"0H)WEXDV$X`.@BN!B(:#A#,"*X`*@(>`$H"K@"L",
MX)2@G>7D[8[@`Z"*X&1!H.&8L)WE`1"*X`2@(N#NS8S@#J`JX`.PB^!NX:#A
M"A"!X`*PB^"<H)WE#B`DX`P@(N#L'8'@`K"+X&S!H.$#H(K@H""=Y02@BN`,
M0"[@X;V+X`%`).`#((+@81&@X0[@@N`!("S@"R`BX`+@CN"D()WE!*"*X.NM
MBN`#((+@:[&@X0S`@N`+("'@"B`BX`+`C."H()WEZNV.X`,P@N!JH:#A`1"#
MX`HP*^#NS8S@#C`CX&[AH.$.((KA`Q"!X`P@`N`.,`K@`R""X:Q`G>7D-9_E
M[!V!X`-`A.!LP:#A"["$X`Q`CN$+((+@`4`$X`RP#N`+0(3AL+"=Y>$M@N`#
ML(O@81&@X0J@B^`*0(3@`:",X0&P#.`"H`K@"Z"*X;2PG>7B383@`["+X&(A
MH.$.X(O@#N"*X`*@@>$"L`'@!*`*X`N@BN&XL)WEY.V.X`.PB^!D0:#A#,"+
MX`S`BN`$H(+A!+`"X`Z@"N`+H(KAO+"=Y>[-C.`#L(O@;N&@X0$0B^`!$(K@
M#J"$X0ZP!.`,H`K@"Z"*X<"PG>7L'8'@`["+X&S!H.$"((O@`B"*X`R@CN$,
ML`[@`:`*X`N@BN'$L)WEX2V"X`.PB^!A$:#A!$"+X`1`BN`!H(SA`;`,X`*@
M"N`+H(KAR+"=Y>)-A.`#L(O@8B&@X0[@B^`.X(K@`J"!X0*P`>`$H`K@"Z"*
MX<RPG>7D[8[@`["+X&1!H.$,P(O@#,"*X`2@@N$$L`+@#J`*X`N@BN'0L)WE
M[LV,X`.PB^!NX:#A`1"+X`$0BN`.H(3A#K`$X`R@"N`+H(KAU+"=Y>P=@>`#
ML(O@;,&@X0(@B^`"((K@#*".X0RP#N`!H`K@"Z"*X=BPG>7A+8+@`["+X&$1
MH.$$0(O@!$"*X`&@C.$!L`S@`J`*X`N@BN'<L)WEXDV$X`.PB^!B(:#A#N"+
MX`[@BN`"H('A`K`!X`2@"N`+H(KAX+"=Y>3MCN`#L(O@9$&@X0S`B^`,P(K@
M!*""X02P`N`.H`K@"Z"*X>2PG>7NS8S@`["+X&[AH.$!$(O@`1"*X`Z@A.$.
ML`3@#*`*X`N@BN'HL)WE[!V!X`.PB^!LP:#A`B"+X`(@BN`,H([A#+`.X`&@
M"N`+H(KA[+"=Y>$M@N`#L(O@81&@X01`B^`$0(K@`:",X0&P#.`"H`K@"Z"*
MX?"PG>7B383@`["+X&(AH.$.X(O@#N"*X`*@@>$"L`'@!*`*X`N@BN'TL)WE
MY.V.X`.PB^!D0:#A#,"+X`S`BN`$H(+A#K`*X`2@`N`*H(OA^+"=Y>[-C.`#
M,(O@`1"#X`$0BN#<,I_E[*V!X/P0G>5NX:#A`Q"!X`(@@>`.$"3@#!`AX`$@
M@N``$9WE;,&@X0,0@>`$0('@#!`NX`H0(>`!0(3@!!&=Y>HM@N`#$('@:J&@
MX0[@@>`*$"S@`A`AX`'@CN`($9WEXDV$X`,0@>!B(:#A#,"!X`(0*N`$$"'@
M`<",X`P1G>7D[8[@`Q"!X&1!H.$*H('@!!`BX`X0(>`!H(K@$!&=Y>[-C.`#
M$('@;N&@X0(@@>`.$"3@#!`AX`$0@N`4(9WE[*V*X`,@@N!LP:#A!$""X`P@
M+N`*("+@`D"$X!@AG>7J'8'@`R""X&JAH.$.X(+@"B`LX`$@(N`"(([@'.&=
MY>%-A.`#X([@81&@X0S`CN`!X"K@!.`NX`[`C.`@X9WEY"V"X`/@CN!D0:#A
M"J".X`3@(>`"X"[@#N"*X"2AG>7BS8S@`Z"*X&(AH.$!$(K@`J`DX`R@*N#L
M[8[@"A"!X&RAH.$HP9WE[AV!X`/`C.`$0(S@"L`BX`[`+.`,P(3@+$&=Y6[A
MH.$#0(3@`B"$X`Y`*N`!0"3@X<V,X`0@@N!A0:#A,!&=Y>PM@N`#$('@"A"!
MX`2@+N`,H"K@"A"!X#2AG>5LP:#A`Z"*X`[@BN`,H"3@`J`JX.(=@>`*X([@
M8J&@X3@AG>7A[8[@`R""X`0@@N`*0"S@`4`DX`0@@N`\09WE81&@X0-`A.`,
MP(3@`4`JX`Y`).`$P(S@0$&=Y>XM@N`#0(3@;N&@X0J@A.`.0"'@`D`DX`2@
MBN!$09WEXLV,X`-`A.!B(:#A`1"$X`)`+N`,0"3@!!"!X$A!G>7LK8K@`S"$
MX`F0@^!LP:#A#N")X`R0(N`*D"G@ZAV!X`G@CN#A[8[@!#"=Y0(@B.``X(#E
M$""`Y4PAG>4`,)/E`7"'X&I1A>`,P(;@`P!2X01P@.4(4(#E#,"`Y0````KG
M^__K5=^-XO"/O>@49P$`+`$``)EY@EJAZ]ENW+P;C];!8LJ<,)_E\$<MZ0!`
M4.(#,(_@(0``"HP@G^4",)/G`)"3Y0``6>,)0*`!&P``"@0PH.$#4*#A`2#3
MY```4N,]`%(3^O__&@1@H.$!H*#A"8"@X0101>`(<*#A!$"8Y```5.,-```*
M!2"@X080H.$$`*#A3?O_ZP``4./U__\:!3#4YST`4^/R__\:"7!'X$=QH.$!
M4(7B`'"*Y05`A.`$`*#A\(>]Z"Q;`0`H`0``$T`MZ30PG^4T()_E`S"/X`)`
MD^<-$*#A`#"4Y00PC>7+___K!""=Y0`PE.4#`%+A````"J;[_^L(T(WB$("]
MZ(!:`0`L`0``]T`MZ0!@H.$-<*#A:$"?Y6@PG^4$0(_@`U"4YP`PE>4$,(WE
M!Q"@X08`H.&V___K``!0XP0``!H$()WE`#"5Y0,`4N$*```*C_O_ZS`PG^4`
M()WE`S"4YP`PD^4",8/@!""3Y0``4N,$((/D^___&NO__^H,T(WB\("]Z#!:
M`0`L`0``*`$``/!/+>D!4*#AN)&?Y;@QG^4)D(_@`S"9YQ303>(`,(WE`#"3
MY0!PH.$,,(WE`##1Y3T`4^,!4($"!0"@X6W[_^L($(WB`("@X0<`H.&,___K
M`$!0X@X```IF^__K"`!0X3,``#H!0$3B`3#5Y```4^,!,.3E^___&@``H.,`
M,)WE#""=Y0`PD^4#`%+A2P``"EO[_^LT,9_E`Z"9YP"PFN4$,9OG``!3XPX`
M`!H@,9_E`F"$X@,PC^``()/E!F&@X0``4N,)```*!A"@X0L`H.&@^O_K``!0
MXP``BN4/```:``#@X^3__^H!0(3BZ___Z@$@H.,&`*#A`""#Y<7Z_^L`,%#B
M!#"-Y?3__PH(($;B"Q"@X<+Z_^L$,)WE`#"*Y0`PFN4&8(/@`#"@XP0P!N4(
M0(WE!S"@X0,`H.$!(-/D``!2XST`4A/Z__\:?#"?Y0<`0.`#0)GG`H"(X@@`
M@.`(D)WE`&"4Y:KZ_^L)`8;G``!0XP`PE!4(()T5`C&3%];__PH!(-?D`Q"@
MX3T`4N,``%(3`2#!Y`8``!H](*#C`"##Y0$@U>0``%+C`2#CY?O__QJO___J
M`3"@X?#__^H4T(WB\(^]Z*Q9`0`L`0``*`$``*A:`0#P3RWI*#&?Y2@AG^4#
M,(_@`F"3YW303>(`,);E`%!0XFPPC>43```*`##5Y0``4^,0```*2/K_ZP!P
M4.(-```*]("?Y?20G^7TH)_E"("/X`F0C^`*H(_@!P"@X67Z_^L``%#C"```
M&@<`H.&"^O_K!0"@X<7Z_^ML()WE`#"6Y0,`4N$H```*Y_K_ZQ-`@.(($*#A
M!`"@X5/Z_^L``%#C[/__"@D0H.$$`*#A3OK_ZP``4./G__\*!0"@X=?Z_^L`
ML*#A!`"@X=3Z_^L``(O@`@"`XEGZ_^L`L*#A!#"@X04@H.$*$*#AP/K_ZPT0
MH.$+`*#AL?K_ZP$`<.,+`*#A!P``"A`PG>4/.@/B`0E3XP,``!JY___K"P"@
MX:3Z_^O,___J0OK_Z_K__^ITT(WB\(^]Z-A7`0`L`0``+1<``"@7```G%P``
M,$`MZ7`PG^5P()_E`S"/X`)`D^=TT$WB`#"4Y0T0H.$`4*#A;#"-Y3[Z_^L`
M`%#C``"@$PD``!H0,)WE#SH#X@H*4^,!"5,3!```&@(0H.,%`*#A_?G_ZQ`/
M;^&@`J#A;""=Y0`PE.4#`%+A````"IOZ_^MTT(WB,("]Z)!6`0`L`0``$T`M
MZ3Q`G^4\,)_E!$"/X`,PE.<``)/E?OK_ZRPPG^4L$)_E`S"4YP$0C^`$,(WE
M(#"?Y00@G>4#,(_@"-"-XA!`O>AM^O_J#%8!`"`!```\`0``C14``$@5```3
M0"WI3#"?Y4P@G^4#,(_@`D"3YP``E.5G^O_KX/__ZP``E.5D^O_K`""@XRPP
MG^4$((WE*!"?Y2@@G^4#,(_@`#"-Y0(@C^`!$(_@S?G_ZPC0C>(0@+WHL%4!
M`"`!``"I%P``+14``/@0``#P02WI&#&?Y1@AG^4#,(_@`G"3YP+:3>(8T$WB
M`BJ-X@`PE^44((+B`#""Y<;Y_^OT,)_E]&"?Y?0@G^4#,(_@#("-X@`PC>4"
M((_@`#"@X080H.$(`*#AK/G_ZP$P@.(&`%/A````FO``\.<``%#C"```J@`P
MH.,#`*#A`CJ-XA0P@^(`()/E`#"7Y0,`4N$@```*/_K_ZP%:C>(04(7B`2J@
MXP40H.$(`*#A[OG_ZP!`4.+N__^Z`0"$XKKY_^L`,%#BZO__"@4`4^$"```J
M!""#X`(`5>'B__\Z!0!3X0(``)H$((7@`@!3X=W__SH&`%3AV___R@0@H.$#
M`*#A!1"@X1?Z_^L`(*#C`#"@X00@P.?7___J`MJ-XAC0C>+P@;WH1%4!`"P!
M``#N%````1```-84``"P___J\$\MZ>@QG^7H(9_E`S"/X$+=3>(",)/G!-!-
MX@!`H.'4`9_E"#"-Y4$MC>(`,)/E/"""X@``C^`!4*#A`#""Y5#^_^LO$*#C
M`&"@X00`H.&G^?_K``!0XPP```J<`9_E!!"@X0``C^!Z_O_K03V-XCPP@^(`
M()/E"#"=Y00`H.$`,)/E`P!2X58```KR^?_K!`"@X>WY_^MD$9_E#`"-Y0$0
MC^`%`*#AUOG_ZP"`H.%0D9_E4+&?Y5"AG^4)D(_@"["/X```6./C__\*`"#8
MY0``4N,)@*`!``!6XPD```H($*#A!@"@X4OY_^L``%#C!```&A@1G^4!$(_@
MP?G_ZP"`H.'N___J"`"@X<_Y_^L`P*#C``"(X`@00.`!('#E+P!2XQ,```H,
M,)WE`2"#X@$@@N`*`%+AQ___RM0@G^6`<(WB`B"/X`101^(`((WE!$"-Y0@P
MH.$+(*#A`1J@XP4`H.$:^?_K`0"`X@$*4.,"``":\`#PYP#`P.7E___J$!"-
MX@4`H.&8^?_K``!0XQ```!I@,!?E#SH#X@()4^,,```:`1"@XP4`H.$%^?_K
M``!0XP<``!I<`)_E!1"@X0``C^`C_O_K!0"@X3GY_^L`0*#AI/__ZD`0G^4`
M`*#C`1"/X,3__^I"W8WB!-"-XO"/O>@(5`$`+`$``+X3``"7$P``:!,``.T2
M```A%```_P\``!`3``#&$@``.Q(``"@2````,*#A`2#3Y```4N,>_R\!+P!2
MXP,`H`'Y___J$$`MZ0!`4.("```*`##4Y0``4^,#```:U`"?Y0``C^`00+WH
M$_G_ZGCY_^L!`$#B``"$X```5.$`,*#A&@``*@`@T^4!`$#B+P!2X_C__PH#
M(*#A`1!2Y"\`4>,/```:`3!#X@,`5.$#(*#A`P``*@`0TN4!,$/B+P!1X_C_
M_PH$($+@`C""X@$*4^,6``"*`2""X@$*4N,-``":\`#PYP(`5.$",*#AZ/__
M.@,`5.'J__\:`##4Y2\`4^,T`)\%``"/`-7__PHL`)_E``"/X-+__^HD,)_E
M!!"@X0,PC^`#`*#A!/G_ZQ"`O>@``*#C$("]Z$T1``"I$```_A```*Q2`0`P
M0"WIK#&?Y:PAG^4#,(_@+-!-X@)`D^<-(*#AG!&?Y0`PE.4!$(_@)#"-Y2K`
M@>(*,('B`N"@X0``D^4$$)/E"#"#X@,`KN@,`%/A#B"@X??__QJP,-/A9`&?
MY;`PSN$``(_@B/W_ZU@!G^5849_E``"/X(3]_^M0`9_E!5"/X```C^"`_?_K
M1`&?Y0``C^!]_?_K/`&?Y0``C^!Z_?_K-`&?Y0``C^!W_?_K+`&?Y0``C^!T
M_?_K)`&?Y0``C^!Q_?_K!0"@X6_]_^L4`9_E``"/X&S]_^L,`9_E``"/X&G]
M_^L$`9_E``"/X%3]_^L`$%#B`0``"@4`H.&$_?_K[`"?Y0``C^!-_?_K`!!0
MX@(```K<`)_E``"/X'S]_^O4`)_E``"/X$7]_^L`$%#B#```"L0`G^4``(_@
M=/W_Z[P0G^6\`)_E`1"/X```C^!O_?_K)""=Y0`PE.4#`%+A$@``"NOX_^N<
M`)_E``"/X#/]_^L`$%#BD`"?%0``CQ#M__\:B!"?Y0H@H.,!$(_@$0"-XFKX
M_^L``%#CY___&G``G^4;$(WB``"/X.+__^HLT(WB,("]Z,10`0`L`0``%!``
M`&@0``!A$```DQ```%D0``!6$```41```%40``#^#P``21```$D0``#;#P``
M.Q```#`0```N$```+1```'8/```U$```G0\``/4/``")#P``Y@\``%T/```0
M0"WI3#"?Y0,PC^``,)/E`0!SXPP``!H\`)_E``"/X`#]_^L``%#C!```"@``
MT.4P`%#C``!0$P$`H!,``*`#&#"?Y0,PC^```(/E$#"?Y0,`G^<0@+WH^$\!
M`,T.``"\3P$`L$\!`!!`+>FE^/_K3?C_ZP``4.,``)`5$("]Z/=`+>F8<)_E
M`$"@X0=PC^`'`*#AX_S_ZP!04.($$*#A`@``"@`PU>4``%/C!```&G``G^4`
M`(_@#-"-XO!`O>@,_?_J*?C_ZP``4.,2```:!`"@X87X_^L`8*#A!0"@X8+X
M_^L``(;@`@"`X@?X_^L`8*#A,#"?Y3`0G^4`4(WE`1"/X`,PC^`$(*#A:_C_
MZP80H.$'`*#AYO__Z@S0C>+P@+WHUPX``*\.``"D#0``@0X``/!/+>EL:)_E
M;#B?Y09@C^`#,);G@=Q-XF303>)<R)_E$#"-Y8$LC>(`,)/E%DZ-X@S`C^!<
M((+B`#""Y1!PC.+4,$3BO.!$X@!0H.$'`)SI!P"#Z`\`M^@/`*[H`P"7Z,@P
M1.(HP(SB`P".Z`<`G.@'`(/H"`B?Y0``C^"<_/_K`'!0X@\```H`,-?E``!3
MXPP```JL___K!P"@X>#W_^L`8*#A@3R-XEPP@^(`()/E$#"=Y08`H.$`,)/E
M`P!2X>D!``H_^/_KF?__ZP!P4.+(@$0"*```"@<`H.$V^/_K@`"@X0$`@.*[
M]__K`*"@X0"`H.&,EY_E`7!'X@F0C^`!(/?E``!2XR$``!J\@$3B!'"8Y```
M5^,,```*!P"@X7/\_^L`<%#B^/__"@`PU^4``%/C]?__"FG]_^L``%#C\O__
M"@<`H.&U]__K`'"@X=201.(:``#J9?S_ZP`P4.(%```*`##3Y0``4^,"```*
MJ_?_ZP!P4.+6__\:!`"8Y```4./S__\:_':?Y0=PC^#0___J"`"@X0D0H.'Z
M]__K`H"(XM7__^H(`*#A3/W_ZP``4.,$```*"`"@X9CW_^L`<*#A``!7XP4`
M`!H$@)GD``!8XS````H`,-CE``!3X_#__QH'`*#A\_?_ZP"0H.$*`*#A\/?_
MZP"0B>`!FXGB!)")X@D`H.%S]__K`("@X7@VG^5X%I_E`S"/X``PC>5P-I_E
M!R"@X0,PC^`!$(_@!*"-Y=3W_^L'':#C"`"@X;_W_^L!`'#C%0``&KGW_^L`
M,)#E$0!3XQ$```HX-I_E`$"5Y0,PEN<`,)/E%#"-Y;#W_^LD%I_E`#"0Y00@
MH.$`,(WE`1"/X`@PH.$4`)WED_?_ZP!@H..!___J"'"@X<___^H@$(WB"`"@
MX5;W_^L`<%#B"```"MPUG^7@%9_E`P"6YP`@E>4(,*#A`1"/X```D.6"]__K
M[?__ZC`Q%.4/.@/B`0E3X_+__QHHH13EM_?_ZP``6N'N__\:,#$4Y8,[H.&C
M.Z#A!PU3X^G__QH)`*#A,/?_ZP!@H.&$!9_E``"/X/+[_^L``%#C80``&@"0
ME>4)`*#AG_?_ZP,`4.,`H*#A&@``FEP5G^4$`$#B`1"/X```B>`*]__K``!0
MXQ,``!H$`%KC`P``"@J@B>`%,%KE+P!3XPT``!H$4)7E``!5XPH```H%`*#A
MBO?_ZP,`4.,&``":$!6?Y00`0.(!$(_@``"%X/;V_^L``%#C!9"@`<3^_^L`
MH%#B`@$`&@D`H.$*$*#A&/?_ZP"04.+]```*`E"@XP`PX.,1(.#C`%"-Y01P
M1.+@]O_K!B"@XP<0H.$)`*#A1??_ZP0P5.4``%/C,P``&@,P5.5#`%/C,```
M&@(P5.5!`%/C+0``&@$P5.5#`%/C*@``&@`PU.5(`%/C)P``&@$PU.5%`%/C
M)```&@`PX.,Y(.#C`%"-Y0D`H.'%]O_K*2"@XP<0H.$)`*#A*O?_ZP@@H.%`
M-)_E0!2?Y0,PC^`$,(WE.#2?Y0!PC>4#,(_@`1"/X`8`H.$]]__K"`"@X2SW
M_^L<!)_E!A"@X0``C^#%^__K!@"@X:7^_^OZ_O_J`)"5Y=CV_^L`$*#A"0"@
MX2?]_^L`D%#BE___&I7__^H`4*#C`#"@XP!0C>4`(*#C"0"@X9_V_^O,,Y_E
MS`.?Y90P!.4$,*#AQ!.?Y4A0(^7T"D3AO`.?Y;P3G^604`3E_`E$X8Q0!.48
M,(WE`BF@XP<0H.$)`*#A]_;_ZP!04.)&``#*"0"@X>WV_^M_$.#CD#`4Y8Q0
M%.4SG[_FHS&@X3\P`^(!((/BB+!$XC@`4N,#$,OG`@"+X#5?O^:\<(WB."!B
MT@`0H-,'``#:0"!BX@`0H..)]O_K!P"@X3#X_^LX(*#C`!"@XPL`H.&#]O_K
M4%`$Y3!01.),D`3E!9"@X0<`H.$F^/_KI#`4Y0RSG^4S/[_F1#`$Y:`P%.5$
M<$3B,S^_YD`P!.6<,!3E"["/X#,_O^8\,`3EF#`4Y3,_O^8X,`3EE#`4Y3,_
MO^8T,`3E!0"@X0$@U^0+$*#A`:"*XMOV_^L4`%KC`E"%XO?__QH`,*#C"#!$
MY:0RG^6D$I_E`S"/X`0PC>6<,I_E`)"-Y0,PC^`((*#A`1"/X(S__^J0,!3E
MA2&@X0(PD^",(!0ED#`$Y0$@@B*,(`0EC#`4Y:4^@^",,`3E2#`4Y0``4^--
M```*0+!CXH@`1.(+`%7A`P"`X`6PH+$'`%#A`@``*@LP@.`#`%?A!```.@<`
M4.$#``":"S"'X`,`4.$````J\`#PYP()6^/\__^*"R"@X0<0H.&M]O_K2#`4
MY0,PB^!``%/C2#`$Y8O__QJD`$3B"U!%X`NPA^#5]__KI#!$X@L0H.$4,(WE
MB+!$XA4``.H8,)WE`0!3X0`PH),!,*"#`0!;X0`PH",``%/CX___&@L`4>%`
M,('B`0``*@,`6^'>__\Z0""@XPL`H.$<,(WECO;_ZQ0`G>6]]__K'#"=Y4!0
M1>(#$*#A/P!5X^?__\J(,$3B`P!1X0(``)H%,(/@`P!1X<W__SJ(,$3B`P!1
MX0(``"H%(('@`@!3X<?__SI$`%7CQ?__B@4@H.&(`$3B=O;_ZTA0!.57___J
M!["@X<W__^H4$9_E%`&?Y0$0C^```(_@^/K_Z^7U_^L$,9_E!!&?Y0,PC^`)
M`(WH_#"?Y0@@H.$#,(_@`1"/X`8`H.%?]O_KZ$"?Y>A0G^7HD)_E!$"/X`50
MC^`)D(_@!QV@XP8`H.%$]O_K`0!PXQ;__QH^]O_K`#"0Y1$`4^,2__\:R_7_
MZP%PA^*!`HWH!#"@X0@@H.$%$*#A!@"@X4CV_^OM___J@=R-XF30C>+PC[WH
M=$T!`"P!``"<3@$`Y@P``$H-``"S#```/`P``!\,``!."P``"`$``-4+``#(
M"P``&@L``)<+``!,"P``-0L``&D*``#R"```N@@``/#ATL,!(T5GB:O-[_[<
MNIAV5#(08@@``'$)``"A"```+@<``%D&``#=!0``O0<````'``!Z!0``7@4`
M`/(&``")!P``^$\MZ2PSG^4L(Y_E`S"/X`)`D^<``)3E%O;_ZP!0H.$``)3E
M$_;_ZV0PU>5E,,#E"`.?Y0``C^!K^O_K``!0XP4```H`,-#E,0!3XP(``!H!
M,-#E``!3XP````K1_/_K``"4Y0/V_^O4$I_E"S"@XP$@H.,!$(_@L_7_ZP``
M4.,=```:``"4Y?KU_^NT$I_E`S"@XP$@H.,!$(_@JO7_ZP!04.)-```:``"4
MY?'U_^N4$I_E`S"@XP$@H.,!$(_@H?7_ZP!04.)A```*?`*?Y0``C^!$^O_K
M`&!0XE$```H``)3EX_7_ZP8@H.$,,)7E`!"3Y9KU_^M5``#J`5"@XPPPD.5(
M@I_E&'"3Y422G^4(@(_@!#"8Y0%@1>(%`%/A``"4Y08``-K2]?_K`#"@XP8@
MH.$'$*#A6?7_ZP"P4.((```:$#*?Y0,PC^`$()/E`2!"X@(`5N')__\:`6"@
MXP-0H.$8``#J"#"8Y0`@F^4%H9/G"#"2Y0DP`^`!"U/C#!"2!08```H``)3E
MN?7_ZP`0F^4",*#C`""@X\'U_^L`$*#A"@"@X33U_^L``%#CX___&@%0A>+5
M___JK?7_ZP<0H.$,]?_K`6"&X@0PE>4``)3E!@!3X??__\JH___J``"4Y:/U
M_^L,,)7E;"&?Y0`0D^4"((_@6?7_ZPPPE>4`,)/E"#"3Y0$%$^.E__\*``"4
MY9?U_^L,,)7E`!"3Y27U_^N?___J/OO_ZP!@4.(``)3E*```"H[U_^L,,)7E
M!B"@X0`0D^5%]?_K!@"@X7SU_^L``)3EAO7_ZP!0H.$``)3E@_7_Z_00G^4!
M(*#C`1"/X.GT_^OH()_E`!"@X0(@C^`%`*#A-?7_ZP``E.5X]?_K`#"@XV4P
MP.7(`)_ER$"?Y0``C^#/^?_K!$"/X```4.,,`(3E#@``&@@`E.4,_?_K``!0
MXPP`A.4)```:G`"?Y0``C^#<]/_K9?7_ZY`PG^4#,(_@"""3Y0PPE>4`()+E
M??__ZGQ`G^4'':#C!$"/X`P`E.5+]?_K`2"`XA$`4.,!`%(3`#"@X?B/O9@(
M$)3E5`"?Y0P@E.4`$)'E``"/X,7T_^ML1`$`(`$``%T$``"C!0``A`4``&<%
M``"/`P``"$4!```$(`#01`$`*@0``+4#``"Z`P``L@$``&Q#`0!L`P``-$,!
M`!A#`0`Q`P``<$`MZ0!`H.'$^__KO/O_ZP!0H.&)_/_K``!0XP``5!-P@+T(
M`##4Y0``4^-P@+T('!"?Y04`H.$!$(_@V_3_ZP``5>%P@+T8!`"@X7!`O>@N
M^O_JD`$```%`+>D!0+WH'O\OX7!E<FQX<VDN8P!?7T5.5E]005)?0TQ%04Y?
M7R`@("`@("`@("`@("`@(```+BX`)7,O)7,`1'EN84QO861E<CHZ8F]O=%]$
M>6YA3&]A9&5R`$EN=&5R;F%L<SHZ4$%2.CI"3T]4`"]P<F]C+R5I+R5S`&5X
M90!005)?5$5-4`!005)?4%)/1TY!344`.@`O`%!%4DPU3$E"`%!%4DQ,24(`
M4$523#5/4%0`4$523$E/`%!!4E])3DE424%,25I%1`!005)?4U!!5TY%1`!0
M05)?0TQ%04X`4$%27T1%0E5'`%!!4E]#04-(10!005)?1TQ/0D%,7T1%0E5'
M`%!!4E]'3$]"04Q?5$U01$E2`%!!4E]435!$25(`4$%27T=,3T)!3%]414U0
M`%!!4E]'3$]"04Q?0TQ%04X`4$%27T-,14%./0`Q`$Q$7TQ)0E)!4EE?4$%4
M2`!365-414T`)3`R>``E<R5S)7,E<P!P87(M`"5S.B!C<F5A=&EO;B!O9B!P
M<FEV871E('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H`)7,Z
M('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&ES('5N<V%F92`H<&QE87-E(')E
M;6]V92!I="!A;F0@<F5T<GD@>6]U<B!O<&5R871I;VXI"@!P87)L`"YP87(`
M)7,E<V-A8VAE+25S)7,`)7,E<W1E;7`M)74E<P`E<R5S=&5M<"TE=2TE=25S
M`$%21U8`&`!P97)L`#``4$%2.CI086-K97(Z.E9%4E-)3TX`,2XP-#<`56YA
M8FQE('1O(&-R96%T92!C86-H92!D:7)E8W1O<GD`)7,Z(&-R96%T:6]N(&]F
M('!R:79A=&4@8V%C:&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\]
M)6DI"@`M90`M+0!54T52`%5315).04U%`%1%35!$25(`5$U0`"]T;7``979A
M;"`G97AE8R`O=7-R+V)I;B]P97)L("`M4R`D,"`D>S$K(B1`(GTG"FEF(#`[
M(",@;F]T(')U;FYI;F<@=6YD97(@<V]M92!S:&5L;`IP86-K86=E(%]?<&%R
M7W!L.PIM>2`H)'!A<E]T96UP+"`D<')O9VYA;64L($!T;7!F:6QE*3L*14Y$
M('L@:68@*"1%3E9[4$%27T-,14%.?2D@>PIR97%U:7)E($9I;&4Z.E1E;7`[
M"G)E<75I<F4@1FEL93HZ0F%S96YA;64["G)E<75I<F4@1FEL93HZ4W!E8SL*
M;7D@)'1O<&1I<B`]($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1P87)?=&5M
M<"D["F]U=',H<7%[4F5M;W9I;F<@9FEL97,@:6X@(B1P87)?=&5M<")]*3L*
M1FEL93HZ1FEN9#HZ9FEN9&1E<'1H*'-U8B![("@@+60@*2`_(')M9&ER(#H@
M=6YL:6YK('TL("1P87)?=&5M<"D["G)M9&ER("1P87)?=&5M<#L*:68@*"UD
M("1P87)?=&5M<"`F)B`D7D\@;F4@)TU35VEN,S(G*2!["FUY("1T;7`@/2!N
M97<@1FEL93HZ5&5M<"@*5$5-4$Q!5$4@/3X@)W1M<%A86%A8)RP*1$E2(#T^
M($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1T;W!D:7(I+`I3549&25@@/3X@
M)RYC;60G+`I53DQ)3DL@/3X@,"P**3L*<')I;G0@)'1M<"`B(R$O8FEN+W-H
M"G@],3L@=VAI;&4@6R!<)'@@+6QT(#$P(%T[(&1O"G)M("UR9B`G)'!A<E]T
M96UP)PII9B!;(%PA("UD("<D<&%R7W1E;7`G(%T[('1H96X*8G)E86L*9FD*
M<VQE97`@,0IX/6!E>'!R(%PD>"`K(#%@"F1O;F4*<FT@)R(@+B`D=&UP+3YF
M:6QE;F%M92`N("(G"B(["F-H;6]D(#`W,#`L)'1M<"T^9FEL96YA;64["FUY
M("1C;60@/2`D=&UP+3YF:6QE;F%M92`N("<@/B]D978O;G5L;"`R/B8Q("8G
M.PIC;&]S92`D=&UP.PIS>7-T96TH)&-M9"D["F]U=',H<7$H4W!A=VYE9"!B
M86-K9W)O=6YD('!R;V-E<W,@=&\@<&5R9F]R;2!C;&5A;G5P.B`I"BX@)'1M
M<"T^9FEL96YA;64I.PI]"GT@?0I"14=)3B!["DEN=&5R;F%L<SHZ4$%2.CI"
M3T]4*"D@:68@9&5F:6YE9"`F26YT97)N86QS.CI005(Z.D)/3U0["F5V86P@
M>PI?<&%R7VEN:71?96YV*"D["FUY("1Q=6EE="`]("$D14Y6>U!!4E]$14)5
M1WT["FUY("5#;VYF:6<@/2`H"G!A=&A?<V5P("`@(#T^("@D7D\@/7X@+UY-
M4U=I;B\@/R`G.R<@.B`G.B<I+`I?97AE("`@("`@("`]/B`H)%Y/(#U^("]>
M*#\Z35-7:6Y\3U,R?&-Y9W=I;BDO(#\@)RYE>&4G(#H@)R<I+`I?9&5L:6T@
M("`@("`]/B`H)%Y/(#U^("]>35-7:6Y\3U,R+R`_("=<7"<@.B`G+R<I+`HI
M.PI?<V5T7W!R;V=N86UE*"D["E]S971?<&%R7W1E;7`H*3L*;7D@*"1S=&%R
M=%]P;W,L("1D871A7W!O<RD["GL*;&]C86P@)%-)1WM?7U=!4DY?7WT@/2!S
M=6(@>WT["F]P96X@7T9(+"`G/"<L("1P<F]G;F%M92!O<B!L87-T.PIB:6YM
M;V1E*%]&2"D["FUY("1B=68["FUY("1S:7IE(#T@+7,@)'!R;V=N86UE.PIM
M>2`D;V9F<V5T(#T@-3$R.PIM>2`D:61X(#T@+3$["G=H:6QE("@Q*0I["B1O
M9F9S970@/2`D<VEZ92!I9B`D;V9F<V5T(#X@)'-I>F4["G-E96L@7T9(+"`M
M)&]F9G-E="P@,B!O<B!D:64@<7%;<V5E:R!F86EL960@;VX@(B1P<F]G;F%M
M92(Z("0A73L*;7D@)&YR96%D(#T@<F5A9"!?1D@L("1B=68L("1O9F9S970[
M"F1I92!Q<5MR96%D(&9A:6QE9"!O;B`B)'!R;V=N86UE(CH@)"%=('5N;&5S
M<R`D;G)E860@/3T@)&]F9G-E=#L*)&ED>"`](')I;F1E>"@D8G5F+"`B7&Y0
M05(N<&U<;B(I.PIL87-T(&EF("1I9'@@/CT@,"!\?"`D;V9F<V5T(#T]("1S
M:7IE('Q\("1O9F9S970@/B`Q,C@@*B`Q,#(T.PHD;V9F<V5T("H](#(["GT*
M;&%S="!U;FQE<W,@)&ED>"`^/2`P.PHD;V9F<V5T("T]("1I9'@@+2`T.PIS
M965K(%]&2"P@+21O9F9S970L(#(["G)E860@7T9(+"`D8G5F+"`T.PIS965K
M(%]&2"P@+21O9F9S970@+2!U;G!A8VLH(DXB+"`D8G5F*2P@,CL*<F5A9"!?
M1D@L("1B=68L(#0["B1D871A7W!O<R`]("AT96QL(%]&2"D@+2`T.PIM>2`E
M<F5Q=6ER95]L:7-T.PIW:&EL92`H)&)U9B!E<2`B1DE,12(I('L*<F5A9"!?
M1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F
M*3L*;7D@)&9U;&QN86UE(#T@)&)U9CL*;W5T<RAQ<2A5;G!A8VMI;F<@9FEL
M92`B)&9U;&QN86UE(BXN+BDI.PIM>2`D8W)C(#T@*"`D9G5L;&YA;64@/7X@
M<WQ>*%MA+69<9%U[.'TI+WQ\("D@/R`D,2`Z('5N9&5F.PIM>2`H)&)A<V5N
M86UE+"`D97AT*2`]("@D8G5F(#U^(&U\*#\Z+BHO*3\H+BHI*%PN+BHI?"D[
M"G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").
M(BP@)&)U9BD["FEF("AD969I;F5D*"1E>'0I(&%N9"`D97AT("%^("]<+B@_
M.G!M?'!L?&EX?&%L*20O:2D@>PIM>2`D9FEL96YA;64@/2!?=&5M<&9I;&4H
M(B1C<F,D97AT(BP@)&)U9BP@,#<U-2D["B1005(Z.DAE879Y.CI&=6QL0V%C
M:&5[)&9U;&QN86UE?2`]("1F:6QE;F%M93L*)%!!4CHZ2&5A=GDZ.D9U;&Q#
M86-H97LD9FEL96YA;65](#T@)&9U;&QN86UE.PI]"F5L<VEF("@@)&9U;&QN
M86UE(#U^(&U\7B\_<VAL:6(O?"!A;F0@9&5F:6YE9"`D14Y6>U!!4E]414U0
M?2`I('L*;7D@)&9I;&5N86UE(#T@7W1E;7!F:6QE*"(D8F%S96YA;64D97AT
M(BP@)&)U9BP@,#<U-2D["F]U=',H(E-(3$E".B`D9FEL96YA;65<;B(I.PI]
M"F5L<V4@>PHD<F5Q=6ER95]L:7-T>R1F=6QL;F%M97T@/0HD4$%2.CI(96%V
M>3HZ36]D=6QE0V%C:&5[)&9U;&QN86UE?2`]('L*8G5F(#T^("1B=68L"F-R
M8R`]/B`D8W)C+`IN86UE(#T^("1F=6QL;F%M92P*?3L*?0IR96%D(%]&2"P@
M)&)U9BP@-#L*?0IL;V-A;"!`24Y#(#T@*'-U8B!["FUY("@D<V5L9BP@)&UO
M9'5L92D@/2!`7SL*<F5T=7)N(&EF(')E9B`D;6]D=6QE(&]R("$D;6]D=6QE
M.PIM>2`D9FEL96YA;64@/2!D96QE=&4@)')E<75I<F5?;&ES='LD;6]D=6QE
M?2!\?"!D;R!["FUY("1K97D["F9O<F5A8V@@*&ME>7,@)7)E<75I<F5?;&ES
M="D@>PIN97AT('5N;&5S<R`O7%$D;6]D=6QE7$4D+SL*)&ME>2`]("1?.R!L
M87-T.PI]"F1E;&5T92`D<F5Q=6ER95]L:7-T>R1K97E](&EF(&1E9FEN960H
M)&ME>2D["GT@;W(@<F5T=7)N.PHD24Y#>R1M;V1U;&5](#T@(B]L;V%D97(O
M)&9I;&5N86UE+R1M;V1U;&4B.PII9B`H)$5.5GM005)?0TQ%04Y](&%N9"!D
M969I;F5D*"9)3SHZ1FEL93HZ;F5W*2D@>PIM>2`D9F@@/2!)3SHZ1FEL92T^
M;F5W7W1M<&9I;&4@;W(@9&EE("0A.PIB:6YM;V1E*"1F:"D["G!R:6YT("1F
M:"`D9FEL96YA;64M/GMB=69].PIS965K*"1F:"P@,"P@,"D["G)E='5R;B`D
M9F@["GT*96QS92!["FUY("1F:6QE;F%M92`](%]T96UP9FEL92@B)&9I;&5N
M86UE+3Y[8W)C?2YP;2(L("1F:6QE;F%M92T^>V)U9GTI.PIO<&5N(&UY("1F
M:"P@)SPG+"`D9FEL96YA;64@;W(@9&EE(")C86XG="!R96%D("1F:6QE;F%M
M93H@)"$B.PIB:6YM;V1E*"1F:"D["G)E='5R;B`D9F@["GT*9&EE(")";V]T
M<W1R87!P:6YG(&9A:6QE9#H@8V%N;F]T(&9I;F0@)&UO9'5L92%<;B(["GTL
M($!)3D,I.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E(%!!4CHZ2&5A=GD[
M"G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17AP;W)T97(Z.DAE879Y
M.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["G)E<75I<F4@24\Z
M.D9I;&4["G=H:6QE("AM>2`D9FEL96YA;64@/2`H<V]R="!K97ES("5R97%U
M:7)E7VQI<W0I6S!=*2!["G5N;&5S<R`H)$E.0WLD9FEL96YA;65](&]R("1F
M:6QE;F%M92`]?B`O0E-$4$%.+RD@>PII9B`H)&9I;&5N86UE(#U^("]<+G!M
M8S\D+VDI('L*<F5Q=6ER92`D9FEL96YA;64["GT*96QS92!["F1O("1F:6QE
M;F%M92!U;FQE<W,@)&9I;&5N86UE(#U^("]S:71E8W5S=&]M:7IE7"YP;"0O
M.PI]"GT*9&5L971E("1R97%U:7)E7VQI<W1[)&9I;&5N86UE?3L*?0IL87-T
M('5N;&5S<R`D8G5F(&5Q(")02UPP,#-<,#`T(CL*)'-T87)T7W!O<R`]("AT
M96QL(%]&2"D@+2`T.PI]"FUY($!P87)?87)G<SL*;7D@*"1O=70L("1B=6YD
M;&4L("1L;V=F:"P@)&-A8VAE7VYA;64I.PID96QE=&4@)$5.5GM005)?05!0
M7U)%55-%?3L@(R!S86YI=&EZ92`H4D554T4@;6%Y(&)E(&$@<V5C=7)I='D@
M<')O8FQE;2D*)'%U:65T(#T@,"!U;FQE<W,@)$5.5GM005)?1$5"54=].PII
M9B`H(21S=&%R=%]P;W,@;W(@*"1!4D=66S!=(&5Q("<M+7!A<BUO<'1I;VYS
M)R`F)B!S:&EF="DI('L*;7D@)61I<W1?8VUD(#T@<7<H"G`@("!B;&EB7W1O
M7W!A<@II("`@:6YS=&%L;%]P87(*=2`@('5N:6YS=&%L;%]P87(*<R`@('-I
M9VY?<&%R"G8@("!V97)I9GE?<&%R"BD["FEF("A`05)'5B!A;F0@)$%21U9;
M,%T@97$@)RTM<F5U<V4G*2!["G-H:69T($!!4D=6.PHD14Y6>U!!4E]!4%!?
M4D554T5](#T@<VAI9G0@0$%21U8["GT*96QS92![(",@;F]R;6%L('!A<FP@
M8F5H879I;W5R"FUY($!A9&1?=&]?:6YC.PIW:&EL92`H0$%21U8I('L*)$%2
M1U9;,%T@/7X@+UXM*%M!24U/0DQB<7!I=7-4=ETI*"XJ*2\@;W(@;&%S=#L*
M:68@*"0Q(&5Q("=))RD@>PIP=7-H($!A9&1?=&]?:6YC+"`D,CL*?0IE;'-I
M9B`H)#$@97$@)TTG*2!["F5V86P@(G5S92`D,B(["GT*96QS:68@*"0Q(&5Q
M("=!)RD@>PIU;G-H:69T($!P87)?87)G<RP@)#(["GT*96QS:68@*"0Q(&5Q
M("=/)RD@>PHD;W5T(#T@)#(["GT*96QS:68@*"0Q(&5Q("=B)RD@>PHD8G5N
M9&QE(#T@)W-I=&4G.PI]"F5L<VEF("@D,2!E<2`G0B<I('L*)&)U;F1L92`]
M("=A;&PG.PI]"F5L<VEF("@D,2!E<2`G<2<I('L*)'%U:65T(#T@,3L*?0IE
M;'-I9B`H)#$@97$@)TPG*2!["F]P96X@)&QO9V9H+"`B/CXB+"`D,B!O<B!D
M:64@(EA86#H@0V%N;F]T(&]P96X@;&]G.B`D(2(["GT*96QS:68@*"0Q(&5Q
M("=4)RD@>PHD8V%C:&5?;F%M92`]("0R.PI]"G-H:69T*$!!4D=6*3L*:68@
M*&UY("1C;60@/2`D9&ES=%]C;61[)#%]*2!["F1E;&5T92`D14Y6>R=005)?
M5$5-4"=].PII;FET7VEN8R@I.PIR97%U:7)E(%!!4CHZ1&ES=#L*)GLB4$%2
M.CI$:7-T.CHD8VUD(GTH*2!U;FQE<W,@0$%21U8["B9[(E!!4CHZ1&ES=#HZ
M)&-M9")]*"1?*2!F;W(@0$%21U8["F5X:70["GT*?0IU;G-H:69T($!)3D,L
M($!A9&1?=&]?:6YC.PI]"GT*:68@*"1O=70I('L*>PIR97%U:7)E($E/.CI&
M:6QE.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*?0IM>2`D<&%R(#T@<VAI9G0H
M0$%21U8I.PIM>2`D>FEP.PII9B`H9&5F:6YE9"`D<&%R*2!["D%R8VAI=F4Z
M.EII<#HZ<V5T0VAU;FM3:7IE*#$R."HQ,#(T*3L*;W!E;B!M>2`D9F@L("<\
M)RP@)'!A<B!O<B!D:64@(D-A;FYO="!F:6YD("<D<&%R)SH@)"$B.PIB:6YM
M;V1E*"1F:"D["F)L97-S*"1F:"P@)TE/.CI&:6QE)RD["B1Z:7`@/2!!<F-H
M:79E.CI::7`M/FYE=SL**"`D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H
M+"`D<&%R*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@*0IO<B!D:64@(E)E
M860@)R1P87(G(&5R<F]R.B`D(2(["GT*;7D@)65N=B`](&1O('L*:68@*"1Z
M:7`@86YD(&UY("1M971A(#T@)'II<"T^8V]N=&5N=',H)TU%5$$N>6UL)RDI
M('L*)&UE=&$@/7X@<R\N*EYP87(Z)"\O;7,["B1M971A(#U^(',O7EQ3+BHO
M+VUS.PHD;65T82`]?B`O7B`@*%M>.ETK*3H@*"XK*20O;6<["GT*?3L*;&]C
M86P@)"\@/2!<-#L*:68@*&1E9FEN960@)'!A<BD@>PIO<&5N(%!!4BP@)SPG
M+"`D<&%R(&]R(&1I92`B)"$Z("1P87(B.PIB:6YM;V1E*%!!4BD["F1I92`B
M)'!A<B!I<R!N;W0@82!005(@9FEL92(@=6YL97-S(#Q005(^(&5Q(")02UPP
M,#-<,#`T(CL*?0I#<F5A=&50871H*"1O=70I(#L*;7D@)&9H(#T@24\Z.D9I
M;&4M/FYE=R@*)&]U="P*24\Z.D9I;&4Z.D]?0U)%050H*2!\($E/.CI&:6QE
M.CI/7U=23TY,62@I('P@24\Z.D9I;&4Z.D]?5%)53D,H*2P*,#<W-RP**2!O
M<B!D:64@)"$["F)I;FUO9&4H)&9H*3L*)"\@/2`H9&5F:6YE9"`D9&%T85]P
M;W,I(#\@7"1D871A7W!O<R`Z('5N9&5F.PIS965K(%]&2"P@,"P@,#L*;7D@
M)&QO861E<B`]('-C86QA<B`\7T9(/CL*:68@*"$D14Y6>U!!4E]615)"051)
M37T@86YD("1L;V%D97(@/7X@+UXH/SHC(7Q<0')E;2DO*2!["G)E<75I<F4@
M4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M
M/FYE=RT^87!P;'DH7"1L;V%D97(L("0P*0I]"F9O<F5A8V@@;7D@)&ME>2`H
M<V]R="!K97ES("5E;G8I('L*;7D@)'9A;"`]("1E;G9[)&ME>7T@;W(@;F5X
M=#L*)'9A;"`](&5V86P@)'9A;"!I9B`D=F%L(#U^("]>6R<B72\["FUY("1M
M86=I8R`](")?7T5.5E]005)?(B`N('5C*"1K97DI("X@(E]?(CL*;7D@)'-E
M="`](")005)?(B`N('5C*"1K97DI("X@(CTD=F%L(CL*)&QO861E<B`]?B!S
M>R1M86=I8R@@*RE]>PHD;6%G:6,@+B`D<V5T("X@*"<@)R!X("AL96YG=&@H
M)#$I("T@;&5N9W1H*"1S970I*2D*?65G.PI]"B1F:"T^<')I;G0H)&QO861E
M<BD["B0O(#T@=6YD968["FEF("@D8G5N9&QE*2!["G)E<75I<F4@4$%2.CI(
M96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PII;FET7VEN
M8R@I.PIR97%U:7)E7VUO9'5L97,H*3L*;7D@0&EN8R`](&=R97`@>R`A+T)3
M1%!!3B\@?0IG<F5P('L**"1B=6YD;&4@;F4@)W-I=&4G*2!O<@HH)%\@;F4@
M)$-O;F9I9SHZ0V]N9FEG>V%R8VAL:6)E>'!](&%N9`HD7R!N92`D0V]N9FEG
M.CI#;VYF:6=[<')I=FQI8F5X<'TI.PI]($!)3D,["FUY("5F:6QE<SL*)&9I
M;&5S>R1??2LK(&9O<B!`1'EN84QO861E<CHZ9&Q?<VAA<F5D7V]B:F5C=',L
M('9A;'5E<R`E24Y#.PIM>2`D;&EB7V5X="`]("1#;VYF:6<Z.D-O;F9I9WML
M:6)?97AT?3L*;7D@)7=R:71T96X["F9O<F5A8V@@*'-O<G0@:V5Y<R`E9FEL
M97,I('L*;7D@*"1N86UE+"`D9FEL92D["F9O<F5A8V@@;7D@)&1I<B`H0&EN
M8RD@>PII9B`H)&YA;64@/2`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1??2D@
M>PHD9FEL92`]("1?.PIL87-T.PI]"F5L<VEF("@O7BA<421D:7)<15PO*"XJ
M6UY#8UTI*5Q:+VDI('L**"1F:6QE+"`D;F%M92D@/2`H)#$L("0R*3L*;&%S
M=#L*?0IE;'-I9B`H;2%>+VQO861E<B];7B]=*R\H+BI;7D-C72E<6B$I('L*
M:68@*&UY("1R968@/2`D4$%2.CI(96%V>3HZ36]D=6QE0V%C:&5[)#%]*2![
M"B@D9FEL92P@)&YA;64I(#T@*"1R968L("0Q*3L*;&%S=#L*?0IE;'-I9B`H
M+68@(B1D:7(O)#$B*2!["B@D9FEL92P@)&YA;64I(#T@*"(D9&ER+R0Q(BP@
M)#$I.PIL87-T.PI]"GT*?0IN97AT('5N;&5S<R!D969I;F5D("1N86UE(&%N
M9"!N;W0@)'=R:71T96Y[)&YA;65]*RL["FYE>'0@:68@(7)E9B@D9FEL92D@
M86YD("1F:6QE(#U^("]<+EQ1)&QI8E]E>'1<120O.PIO=71S*"!J;VEN("(B
M+`IQ<2A086-K:6YG("(I+"!R968@)&9I;&4@/R`D9FEL92T^>VYA;65](#H@
M)&9I;&4L"G%Q*"(N+BXI"BD["FUY("1C;VYT96YT.PII9B`H<F5F*"1F:6QE
M*2D@>PHD8V]N=&5N="`]("1F:6QE+3Y[8G5F?3L*?0IE;'-E('L*;W!E;B!&
M24Q%+"`G/"<L("1F:6QE(&]R(&1I92`B0V%N)W0@;W!E;B`D9FEL93H@)"$B
M.PIB:6YM;V1E*$9)3$4I.PHD8V]N=&5N="`](#Q&24Q%/CL*8VQO<V4@1DE,
M13L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YN97<M/F%P<&QY*%PD8V]N=&5N
M="P@)&9I;&4I"FEF("$D14Y6>U!!4E]615)"051)37T@86YD("1N86UE(#U^
M("]<+B@_.G!M?&EX?&%L*20O:3L*4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N
M="T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE+"`D;F%M92D["GT*;W5T
M<RAQ<2A7<FET=&5N(&%S("(D;F%M92(I*3L*)&9H+3YP<FEN="@B1DE,12(I
M.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H)&YA;64I("L@.2DI.PHD
M9F@M/G!R:6YT*'-P<FEN=&8H"B(E,#AX+R5S(BP@07)C:&EV93HZ6FEP.CIC
M;VUP=71E0U)#,S(H)&-O;G1E;G0I+"`D;F%M90HI*3L*)&9H+3YP<FEN="AP
M86-K*"=.)RP@;&5N9W1H*"1C;VYT96YT*2DI.PHD9F@M/G!R:6YT*"1C;VYT
M96YT*3L*?0I]"B1Z:7`M/G=R:71E5&]&:6QE2&%N9&QE*"1F:"D@:68@)'II
M<#L*)&-A8VAE7VYA;64@/2!S=6)S='(@)&-A8VAE7VYA;64L(#`L(#0P.PII
M9B`H(21C86-H95]N86UE(&%N9"!M>2`D;71I;64@/2`H<W1A="@D;W5T*2E;
M.5TI('L*;7D@)&-T>"`](&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!.R!$
M:6=E<W0Z.E-(02T^;F5W*#$I('T*?'P@979A;"![(')E<75I<F4@1&EG97-T
M.CI32$$Q.R!$:6=E<W0Z.E-(03$M/FYE=R!]"GQ\(&5V86P@>R!R97%U:7)E
M($1I9V5S=#HZ340U.R!$:6=E<W0Z.DU$-2T^;F5W('T["FUY("1S:&%?=F5R
M<VEO;B`](&5V86P@>R`D1&EG97-T.CI32$$Z.E9%4E-)3TX@?2!\?"`P.PII
M9B`H)'-H85]V97)S:6]N(&5Q("<U+C,X)R!O<B`D<VAA7W9E<G-I;VX@97$@
M)S4N,SDG*2!["B1C='@M/F%D9&9I;&4H)&]U="P@(F(B*2!I9B`H)&-T>"D[
M"GT*96QS92!["FEF("@D8W1X(&%N9"!O<&5N*&UY("1F:"P@(CPD;W5T(BDI
M('L*8FEN;6]D92@D9F@I.PHD8W1X+3YA9&1F:6QE*"1F:"D["F-L;W-E*"1F
M:"D["GT*?0HD8V%C:&5?;F%M92`]("1C='@@/R`D8W1X+3YH97AD:6=E<W0@
M.B`D;71I;64["GT*)&-A8VAE7VYA;64@+CT@(EPP(B!X("@T,2`M(&QE;F=T
M:"`D8V%C:&5?;F%M92D["B1C86-H95]N86UE("X](")#04-(12(["B1F:"T^
M<')I;G0H)&-A8VAE7VYA;64I.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"`D9F@M
M/G1E;&P@+2!L96YG=&@H)&QO861E<BDI*3L*)&9H+3YP<FEN="@B7&Y005(N
M<&U<;B(I.PHD9F@M/F-L;W-E.PIC:&UO9"`P-S4U+"`D;W5T.PIE>&ET.PI]
M"GL*;&%S="!U;FQE<W,@9&5F:6YE9"`D<W1A<G1?<&]S.PI?9FEX7W!R;V=N
M86UE*"D["G)E<75I<F4@4$%2.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A
M9&5R*"D["GL*<F5Q=6ER92!&:6QE.CI&:6YD.PIR97%U:7)E($%R8VAI=F4Z
M.EII<#L*?0IM>2`D>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["FUY("1F:"`]
M($E/.CI&:6QE+3YN97<["B1F:"T^9F1O<&5N*&9I;&5N;RA?1D@I+"`G<B<I
M(&]R(&1I92`B)"$Z("1`(CL*)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F
M:"P@)'!R;V=N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@;W(@9&EE
M("(D(3H@)$`B.PIP=7-H($!005(Z.DQI8D-A8VAE+"`D>FEP.PHD4$%2.CI,
M:6)#86-H97LD<')O9VYA;65](#T@)'II<#L*)'%U:65T(#T@(21%3E9[4$%2
M7T1%0E5'?3L*;W5T<RAQ<2A<)$5.5GM005)?5$5-4'T@/2`B)$5.5GM005)?
M5$5-4'TB*2D["FEF("AD969I;F5D("1%3E9[4$%27U1%35!]*2![(",@<VAO
M=6QD(&)E('-E="!A="!T:&ES('!O:6YT(0IF;W)E86-H(&UY("1M96UB97(@
M*"`D>FEP+3YM96UB97)S("D@>PIN97AT(&EF("1M96UB97(M/FES1&ER96-T
M;W)Y.PIM>2`D;65M8F5R7VYA;64@/2`D;65M8F5R+3YF:6QE3F%M93L*;F5X
M="!U;FQE<W,@)&UE;6)E<E]N86UE(#U^(&U["EX*+S]S:&QI8B\**#\Z)$-O
M;F9I9SHZ0V]N9FEG>W9E<G-I;VY]+RD_"B@_.B1#;VYF:6<Z.D-O;F9I9WMA
M<F-H;F%M97TO*3\**%M>+UTK*0HD"GUX.PIM>2`D97AT<F%C=%]N86UE(#T@
M)#$["FUY("1D97-T7VYA;64@/2!&:6QE.CI3<&5C+3YC871F:6QE*"1%3E9[
M4$%27U1%35!]+"`D97AT<F%C=%]N86UE*3L*:68@*"UF("1D97-T7VYA;64@
M)B8@+7,@7R`]/2`D;65M8F5R+3YU;F-O;7!R97-S9613:7IE*"DI('L*;W5T
M<RAQ<2A3:VEP<&EN9R`B)&UE;6)E<E]N86UE(B!S:6YC92!I="!A;')E861Y
M(&5X:7-T<R!A="`B)&1E<W1?;F%M92(I*3L*?2!E;'-E('L*;W5T<RAQ<2A%
M>'1R86-T:6YG("(D;65M8F5R7VYA;64B('1O("(D9&5S=%]N86UE(BDI.PHD
M;65M8F5R+3YE>'1R86-T5&]&:6QE3F%M960H)&1E<W1?;F%M92D["F-H;6]D
M*#`U-34L("1D97-T7VYA;64I(&EF("1>3R!E<2`B:'!U>"(["GT*?0I]"GT*
M=6YL97-S("@D4$%2.CI,:6)#86-H97LD<')O9VYA;65]*2!["F1I92`\/"`B
M+B(@=6YL97-S($!!4D=6.PI5<V%G93H@)#`@6R`M06QI8BYP87(@72!;("U)
M9&ER(%T@6R`M36UO9'5L92!=(%L@<W)C+G!A<B!=(%L@<')O9W)A;2YP;"!=
M"B0P(%L@+4)\+6(@72!;+4]O=71F:6QE72!S<F,N<&%R"BX*)$5.5GM005)?
M4%)/1TY!345](#T@)'!R;V=N86UE(#T@)#`@/2!S:&EF="A`05)'5BD["GT*
M<W5B($-R96%T95!A=&@@>PIM>2`H)&YA;64I(#T@0%\["G)E<75I<F4@1FEL
M93HZ0F%S96YA;64["FUY("@D8F%S96YA;64L("1P871H+"`D97AT*2`]($9I
M;&4Z.D)A<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L("@G7"XN*B<I*3L*<F5Q
M=6ER92!&:6QE.CI0871H.PI&:6QE.CI0871H.CIM:W!A=&@H)'!A=&@I('5N
M;&5S<R@M92`D<&%T:"D[(",@;6MP871H(&1I97,@=VET:"!E<G)O<@I]"G-U
M8B!R97%U:7)E7VUO9'5L97,@>PIR97%U:7)E(&QI8CL*<F5Q=6ER92!$>6YA
M3&]A9&5R.PIR97%U:7)E(&EN=&5G97(["G)E<75I<F4@<W1R:6-T.PIR97%U
M:7)E('=A<FYI;F=S.PIR97%U:7)E('9A<G,["G)E<75I<F4@0V%R<#L*<F5Q
M=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%<G)N;SL*<F5Q=6ER92!%>'!O
M<G1E<CHZ2&5A=GD["G)E<75I<F4@17AP;W)T97(["G)E<75I<F4@1F-N=&P[
M"G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI3<&5C.PIR97%U
M:7)E(%A33&]A9&5R.PIR97%U:7)E($-O;F9I9SL*<F5Q=6ER92!)3SHZ2&%N
M9&QE.PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($-O;7!R97-S.CI:;&EB
M.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!005(["G)E<75I<F4@
M4$%2.CI(96%V>3L*<F5Q=6ER92!005(Z.D1I<W0["G)E<75I<F4@4$%2.CI&
M:6QT97(Z.E!O9%-T<FEP.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0871C:$-O
M;G1E;G0["G)E<75I<F4@871T<FEB=71E<SL*979A;"![(')E<75I<F4@0W=D
M('T["F5V86P@>R!R97%U:7)E(%=I;C,R('T["F5V86P@>R!R97%U:7)E(%-C
M86QA<CHZ571I;"!].PIE=F%L('L@<F5Q=6ER92!!<F-H:79E.CI5;GII<#HZ
M0G5R<W0@?3L*979A;"![(')E<75I<F4@5&EE.CI(87-H.CI.86UE9$-A<'1U
M<F4@?3L*979A;"![(')E<75I<F4@4&5R;$E/.R!R97%U:7)E(%!E<FQ)3SHZ
M<V-A;&%R('T["F5V86P@>R!R97%U:7)E('5T9C@@?3L*?0IS=6(@7W-E=%]P
M87)?=&5M<"!["FEF("AD969I;F5D("1%3E9[4$%27U1%35!](&%N9"`D14Y6
M>U!!4E]414U0?2`]?B`O*"XK*2\I('L*)'!A<E]T96UP(#T@)#$["G)E='5R
M;CL*?0IF;W)E86-H(&UY("1P871H("@**&UA<"`D14Y6>R1??2P@<7<H(%!!
M4E]435!$25(@5$U01$E2(%1%35!$25(@5$5-4"!435`@*2DL"G%W*"!#.EQ<
M5$5-4"`O=&UP("X@*0HI('L*;F5X="!U;FQE<W,@9&5F:6YE9"`D<&%T:"!A
M;F0@+60@)'!A=&@@86YD("UW("1P871H.PIM>2`D=7-E<FYA;64["FUY("1P
M=W5I9#L*979A;"![*"1P=W5I9"D@/2!G971P=W5I9"@D/BD@:68@9&5F:6YE
M9"`D/CM].PII9B`H(&1E9FEN960H)E=I;C,R.CI,;V=I;DYA;64I("D@>PHD
M=7-E<FYA;64@/2`F5VEN,S(Z.DQO9VEN3F%M93L*?0IE;'-I9B`H9&5F:6YE
M9"`D<'=U:60I('L*)'5S97)N86UE(#T@)'!W=6ED.PI]"F5L<V4@>PHD=7-E
M<FYA;64@/2`D14Y6>U5315).04U%?2!\?"`D14Y6>U5315)]('Q\("=365-4
M14TG.PI]"B1U<V5R;F%M92`]?B!S+UQ7+U\O9SL*;7D@)'-T;7!D:7(@/2`B
M)'!A=&@D0V]N9FEG>U]D96QI;7UP87(M(BYU;G!A8VLH(D@J(BP@)'5S97)N
M86UE*3L*;6MD:7(@)'-T;7!D:7(L(#`W-34["FEF("@A)$5.5GM005)?0TQ%
M04Y](&%N9"!M>2`D;71I;64@/2`H<W1A="@D<')O9VYA;64I*5LY72D@>PIO
M<&5N("AM>2`D9F@L("(\(BX@)'!R;V=N86UE*3L*<V5E:R`D9F@L("TQ."P@
M,CL*<WES<F5A9"`D9F@L(&UY("1B=68L(#8["FEF("@D8G5F(&5Q(")<,$-!
M0TA%(BD@>PIS965K("1F:"P@+34X+"`R.PIS>7-R96%D("1F:"P@)&)U9BP@
M-#$["B1B=68@/7X@<R]<,"\O9SL*)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E
M;&EM?6-A8VAE+2(@+B`D8G5F.PI]"F5L<V4@>PIM>2`D8W1X(#T@979A;"![
M(')E<75I<F4@1&EG97-T.CI32$$[($1I9V5S=#HZ4TA!+3YN97<H,2D@?0I\
M?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03$[($1I9V5S=#HZ4TA!,2T^
M;F5W('T*?'P@979A;"![(')E<75I<F4@1&EG97-T.CI-1#4[($1I9V5S=#HZ
M340U+3YN97<@?3L*;7D@)'-H85]V97)S:6]N(#T@979A;"![("1$:6=E<W0Z
M.E-(03HZ5D524TE/3B!]('Q\(#`["FEF("@D<VAA7W9E<G-I;VX@97$@)S4N
M,S@G(&]R("1S:&%?=F5R<VEO;B!E<2`G-2XS.2<I('L*)&-T>"T^861D9FEL
M92@D<')O9VYA;64L(")B(BD@:68@*"1C='@I.PI]"F5L<V4@>PII9B`H)&-T
M>"!A;F0@;W!E;BAM>2`D9F@L("(\)'!R;V=N86UE(BDI('L*8FEN;6]D92@D
M9F@I.PHD8W1X+3YA9&1F:6QE*"1F:"D["F-L;W-E*"1F:"D["GT*?0HD<W1M
M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]8V%C:&4M(B`N("@@)&-T>"`_("1C
M='@M/FAE>&1I9V5S="`Z("1M=&EM92`I.PI]"F-L;W-E*"1F:"D["GT*96QS
M92!["B1%3E9[4$%27T-,14%.?2`](#$["B1S=&UP9&ER("X]("(D0V]N9FEG
M>U]D96QI;7UT96UP+20D(CL*?0HD14Y6>U!!4E]414U0?2`]("1S=&UP9&ER
M.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*;&%S=#L*?0HD<&%R7W1E;7`@/2`D
M,2!I9B`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N
M*RDO.PI]"G-U8B!?=&5M<&9I;&4@>PIM>2`H)&YA;64L("1C;VYT96YT<RP@
M)&UO9&4I(#T@0%\["FUY("1F=6QL;F%M92`]("(D<&%R7W1E;7`O)&YA;64B
M.PIU;FQE<W,@*"UE("1F=6QL;F%M92D@>PIM>2`D=&5M<&YA;64@/2`B)&9U
M;&QN86UE+B0D(CL*;W!E;B!M>2`D9F@L("<^)RP@)'1E;7!N86UE(&]R(&1I
M92`B8V%N)W0@=W)I=&4@)'1E;7!N86UE.B`D(2(["F)I;FUO9&4@)&9H.PIP
M<FEN="`D9F@@)&-O;G1E;G1S.PIC;&]S92`D9F@["F-H;6]D("1M;V1E+"`D
M=&5M<&YA;64@:68@9&5F:6YE9"`D;6]D93L*<F5N86UE*"1T96UP;F%M92P@
M)&9U;&QN86UE*2!O<B!U;FQI;FLH)'1E;7!N86UE*3L*?0IR971U<FX@)&9U
M;&QN86UE.PI]"G-U8B!?<V5T7W!R;V=N86UE('L*:68@*&1E9FEN960@)$5.
M5GM005)?4%)/1TY!345](&%N9"`D14Y6>U!!4E]04D]'3D%-17T@/7X@+R@N
M*RDO*2!["B1P<F]G;F%M92`]("0Q.PI]"B1P<F]G;F%M92!\?#T@)#`["FEF
M("@D14Y6>U!!4E]414U0?2!A;F0@:6YD97@H)'!R;V=N86UE+"`D14Y6>U!!
M4E]414U0?2D@/CT@,"D@>PHD<')O9VYA;64@/2!S=6)S='(H)'!R;V=N86UE
M+"!R:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI("L@,2D["GT*
M:68@*"$D14Y6>U!!4E]04D]'3D%-17T@;W(@:6YD97@H)'!R;V=N86UE+"`D
M0V]N9FEG>U]D96QI;7TI(#X](#`I('L*:68@*&]P96X@;7D@)&9H+"`G/"<L
M("1P<F]G;F%M92D@>PIR971U<FX@:68@+7,@)&9H.PI]"FEF("@M<R`B)'!R
M;V=N86UE)$-O;F9I9WM?97AE?2(I('L*)'!R;V=N86UE("X]("1#;VYF:6=[
M7V5X97T["G)E='5R;CL*?0I]"F9O<F5A8V@@;7D@)&1I<B`H<W!L:70@+UQ1
M)$-O;F9I9WMP871H7W-E<'U<12\L("1%3E9[4$%42'TI('L*;F5X="!I9B!E
M>&ES=',@)$5.5GM005)?5$5-4'T@86YD("1D:7(@97$@)$5.5GM005)?5$5-
M4'T["B1D:7(@/7X@<R]<421#;VYF:6=[7V1E;&EM?5Q%)"\O.PHH*"1P<F]G
M;F%M92`]("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?
M97AE?2(I+"!L87-T*0II9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G
M;F%M921#;VYF:6=[7V5X97TB.PHH*"1P<F]G;F%M92`]("(D9&ER)$-O;F9I
M9WM?9&5L:6U])'!R;V=N86UE(BDL(&QA<W0I"FEF("US("(D9&ER)$-O;F9I
M9WM?9&5L:6U])'!R;V=N86UE(CL*?0I]"G-U8B!?9FEX7W!R;V=N86UE('L*
M)#`@/2`D<')O9VYA;64@?'P]("1%3E9[4$%27U!23T=.04U%?3L*:68@*&EN
M9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`\(#`I('L*)'!R;V=N
M86UE(#T@(BXD0V]N9FEG>U]D96QI;7TD<')O9VYA;64B.PI]"FUY("1P=V0@
M/2`H9&5F:6YE9"`F0W=D.CIG971C=V0I(#\@0W=D.CIG971C=V0H*0HZ("@H
M9&5F:6YE9"`F5VEN,S(Z.D=E=$-W9"D@/R!7:6XS,CHZ1V5T0W=D*"D@.B!@
M<'=D8"D["F-H;VUP*"1P=V0I.PHD<')O9VYA;64@/7X@<R]>*#\]7"Y<+C]<
M421#;VYF:6=[7V1E;&EM?5Q%*2\D<'=D)$-O;F9I9WM?9&5L:6U]+SL*)$5.
M5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE.PI]"G-U8B!?<&%R7VEN:71?
M96YV('L*:68@*"`D14Y6>U!!4E])3DE424%,25I%1'TK*R`]/2`Q("D@>PIR
M971U<FX["GT@96QS92!["B1%3E9[4$%27TE.251)04Q)6D5$?2`](#(["GT*
M9F]R("AQ=R@@4U!!5TY%1"!414U0($-,14%.($1%0E5'($-!0TA%(%!23T=.
M04U%($%21T,@05)'5E\P("D@*2!["F1E;&5T92`D14Y6>R=005)?)RXD7WT[
M"GT*9F]R("AQ=R\@5$U01$E2(%1%35`@0TQ%04X@1$5"54<@+RD@>PHD14Y6
M>R=005)?)RXD7WT@/2`D14Y6>R=005)?1TQ/0D%,7R<N)%]](&EF(&5X:7-T
M<R`D14Y6>R=005)?1TQ/0D%,7R<N)%]].PI]"FUY("1P87)?8VQE86X@/2`B
M7U]%3E9?4$%27T-,14%.7U\@("`@("`@("`@("`@("`B.PII9B`H)$5.5GM0
M05)?5$5-4'TI('L*9&5L971E("1%3E9[4$%27T-,14%.?3L*?0IE;'-I9B`H
M(65X:7-T<R`D14Y6>U!!4E]'3$]"04Q?0TQ%04Y]*2!["FUY("1V86QU92`]
M('-U8G-T<B@D<&%R7V-L96%N+"`Q,B`K(&QE;F=T:"@B0TQ%04XB*2D["B1%
M3E9[4$%27T-,14%.?2`]("0Q(&EF("1V86QU92`]?B`O7E!!4E]#3$5!3CTH
M7%,K*2\["GT*?0IS=6(@;W5T<R!["G)E='5R;B!I9B`D<75I970["FEF("@D
M;&]G9F@I('L*<')I;G0@)&QO9V9H(")`7UQN(CL*?0IE;'-E('L*<')I;G0@
M(D!?7&XB.PI]"GT*<W5B(&EN:71?:6YC('L*<F5Q=6ER92!#;VYF:6<["G!U
M<V@@0$E.0RP@9W)E<"!D969I;F5D+"!M87`@)$-O;F9I9SHZ0V]N9FEG>R1?
M?2P@<7<H"F%R8VAL:6)E>'`@<')I=FQI8F5X<"!S:71E87)C:&5X<"!S:71E
M;&EB97AP"G9E;F1O<F%R8VAE>'`@=F5N9&]R;&EB97AP"BD["GT*<&%C:V%G
M92!M86EN.PIR97%U:7)E(%!!4CL*=6YS:&EF="!`24Y#+"!<)E!!4CHZ9FEN
M9%]P87(["E!!4BT^:6UP;W)T*$!P87)?87)G<RD["F1I92!Q<2AP87(N<&PZ
M($-A;B=T(&]P96X@<&5R;"!S8W)I<'0@(B1P<F]G;F%M92(Z($YO('-U8V@@
M9FEL92!O<B!D:7)E8W1O<GE<;BD*=6YL97-S("UE("1P<F]G;F%M93L*9&\@
M)'!R;V=N86UE.PI#3U)%.CIE>&ET*"0Q*2!I9B`H)$`@/7XO7E]42U]%6$E4
M7UPH*%QD*RE<*2\I.PID:64@)$`@:68@)$`["GT["B0Z.E]?15)23U(@/2`D
M0"!I9B`D0#L*?0I#3U)%.CIE>&ET*"0Q*2!I9B`H)#HZ7U]%4E)/4B`]?B]>
M7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D.CI?7T524D]2(&EF("0Z.E]?
M15)23U(["C$["E]?14Y$7U\*````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!$%P``N!8```$````!`````0```.$"```/````
M<`0```P````($```#0```!0^```9````P'T!`!L````$````&@```,1]`0`<
M````!````/7^_V\L`0``!0```)@(```&````"`(```H```".!```"P```!``
M```5``````````,```"X?@$``@```/`!```4````$0```!<````8#@``$0``
M`"@-```2````\````!,````(````&`````````#[__]O`0``"/K__V\0````
M`````````````````````````````````````````````````````,A]`0``
M`````````!00```4$```%!```!00```4$```%!```!00```4$```%!```!00
M```4$```%!```!00```4$```%!```!00```4$```%!```!00```4$```%!``
M`!00```4$```%!```!00```4$```%!```!00```4$```%!```!00```4$```
M%!```!00```4$```%!```!00```4$```%!```!00```4$```%!```!00```4
M$```%!```!00```4$```%!```!00```4$```%!```!00```4$```%!```!00
M```4$```%!```!00```4$```%!```!00```4$```$!,`````````````%#X`
M````````````"!``````````````````````````````````````````````
M````````````@`$`_____P)!``!-/@```````"X_```G/P``]D```$0_``#^
M0````````.A```#M0`````````=!``!'0T,Z("A!;'!I;F4@."XR+C`I(#@N
M,BXP`$$R````865A8FD``2@````%-EI+``8'"`$)`0H"$@03`10!%0$7`Q@!
M&@(<`1X$(@%$`0`N<VAS=')T86(`+FEN=&5R<``N9VYU+FAA<V@`+F1Y;G-Y
M;0`N9'EN<W1R`"YR96PN9'EN`"YR96PN<&QT`"YI;FET`"YT97AT`"YF:6YI
M`"YR;V1A=&$`+F5H7V9R86UE`"YI;FET7V%R<F%Y`"YF:6YI7V%R<F%Y`"YD
M>6YA;6EC`"YG;W0`+F1A=&$`+F)S<P`N8V]M;65N=``N05)-+F%T=')I8G5T
M97,`````````````````````````````````````````````````````````
M"P````$````"````%`$``!0!```8```````````````!`````````!,```#V
M__]O`@```"P!```L`0``W`````,`````````!`````0````=````"P````(`
M```(`@``"`(``)`&```$`````P````0````0````)0````,````"````F`@`
M`)@(``".!``````````````!`````````"T````)`````@```"@-```H#0``
M\`````,`````````!`````@````V````"0```$(````8#@``&`X``/`!```#
M````$`````0````(````/P````$````&````"!````@0```,````````````
M```$`````````#H````!````!@```!00```4$```_`(`````````````!```
M``0```!%`````0````8````0$P``$!,```0K``````````````0`````````
M2P````$````&````%#X``!0^```,```````````````$`````````%$````!
M`````@```"`^```@/@``&S\``````````````0````````!9`````0````(`
M```\?0``/'T```0```````````````0`````````8P````X````#````P'T!
M`,!]```$```````````````$````!````&\````/`````P```,1]`0#$?0``
M!```````````````!`````0```![````!@````,```#(?0$`R'T``/`````$
M``````````0````(````A`````$````#````N'X!`+A^``!(`0``````````
M```$````!````(D````!`````P````"``0``@```/```````````````!```
M``````"/````"`````,````\@`$`/(```#`0``````````````0`````````
ME`````$````P`````````#R````:```````````````!`````0```)T````#
M``!P``````````!6@```,P```````````````0`````````!`````P``````
>````````B8```*T```````````````$`````````
